#[non_exhaustive]pub struct ConsolidateResponse {
pub topic_document_id: Uuid,
pub topic_name: String,
pub source_count: usize,
pub version: u32,
pub superseded_id: Option<Uuid>,
pub member_ids: Vec<Uuid>,
pub content_hash: String,
pub consolidation_event_id: Uuid,
pub revision_event_id: Option<Uuid>,
}Expand description
Result of a consolidation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.topic_document_id: UuidId of the newly created topic document.
topic_name: StringEchoes the request topic name.
source_count: usizeNumber of distinct member memories collected.
version: u32Version of the topic document (1, or old.version + 1 on revision).
superseded_id: Option<Uuid>Id of the topic document this one superseded, if any.
member_ids: Vec<Uuid>The distinct member ids, in the deterministic order used for synthesis.
content_hash: StringHex-encoded SHA-256 content hash of the (plaintext) document body.
consolidation_event_id: UuidId of the emitted EventType::MemoryConsolidated audit event.
revision_event_id: Option<Uuid>Id of the emitted EventType::MemoryRevised audit event (revision only).