pub async fn execute_recall_plan(
engine: &MnemoEngine,
request: RecallPlanRequest,
) -> Result<RecallPlanResponse>Expand description
RECALL_PLAN — return the best replayable plan for a query, or a miss.
pub async fn execute_recall_plan(
engine: &MnemoEngine,
request: RecallPlanRequest,
) -> Result<RecallPlanResponse>RECALL_PLAN — return the best replayable plan for a query, or a miss.