Structs
- Consolidation
Result - Decay
Pass Result - TtlError
- TtlReport
- Report from a single TTL sweep pass.
Enums
- Decay
Function - Custom decay function types.
Functions
- effective_
importance - Compute effective importance using the specified or default decay curve.
Default (Exponential):
base_importance * e^(-decay_rate * hours) + 0.05 * ln(1 + access_count) - effective_
importance_ with - run_
consolidation - Consolidate episodic memories into semantic summaries. Clusters by tag overlap and creates consolidated semantic memories.
- run_
decay_ pass - Run a decay pass over all active memories for the given agent.
Memories below
forget_thresholdare marked Forgotten. Memories belowarchive_threshold(but above forget) are marked Archived. - run_
ttl_ sweep - Hard-delete every memory whose
expires_atis in the past.