pub fn effective_importance(record: &MemoryRecord) -> f32Expand description
Compute effective importance using the specified or default decay curve.
Default (Exponential): base_importance * e^(-decay_rate * hours) + 0.05 * ln(1 + access_count)
pub fn effective_importance(record: &MemoryRecord) -> f32Compute effective importance using the specified or default decay curve.
Default (Exponential): base_importance * e^(-decay_rate * hours) + 0.05 * ln(1 + access_count)