ConsolidationResult

Struct ConsolidationResult 

#[non_exhaustive]
pub struct ConsolidationResult { pub clusters_found: usize, pub new_memories_created: usize, pub originals_consolidated: usize, pub clusters_skipped_below_threshold: usize, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
clusters_found: usizenew_memories_created: usizeoriginals_consolidated: usizeclusters_skipped_below_threshold: usize

v0.4.10 — number of clusters skipped because the engine has a crate::query::maturity::ConsolidationPolicy::MaturityDriven policy attached and the cluster’s combined maturity score did not clear the configured threshold. Always zero under the default FixedSize policy.

Implementations

Source

impl ConsolidationResult

pub fn new( clusters_found: usize, new_memories_created: usize, originals_consolidated: usize, ) -> Self