pub async fn update_agent_profile(
engine: &MnemoEngine,
record: &MemoryRecord,
) -> Result<()>Expand description
Update the agent profile with statistics from the new memory.
pub async fn update_agent_profile(
engine: &MnemoEngine,
record: &MemoryRecord,
) -> Result<()>Update the agent profile with statistics from the new memory.