pub fn read_persistence_version(conn: &Connection) -> Result<Option<u32>>Expand description
Read the stored persistence version, or None if the marker is absent
(i.e. this is a fresh database OR a pre-0.3.2 file).
pub fn read_persistence_version(conn: &Connection) -> Result<Option<u32>>Read the stored persistence version, or None if the marker is absent
(i.e. this is a fresh database OR a pre-0.3.2 file).